@@ -18,12 +18,12 @@ use tauri_utils::{
 };
 
 const TAURI_GITIGNORE: &[u8] = include_bytes!("../../tauri.gitignore");
-// path to the Tauri app (Rust crate) directory, usually <cwd>/src-tauri
+// path to the Tauri app (Rust crate) directory, usually `<project>/src-tauri/`
 const ENV_TAURI_APP_PATH: &str = "TAURI_APP_PATH";
-// path to the frontend app directory
+// path to the frontend app directory, usually `<project>/`
 const ENV_TAURI_FRONTEND_PATH: &str = "TAURI_FRONTEND_PATH";
 
-static APP_DIR: OnceLock<PathBuf> = OnceLock::new();
+static FRONTEND_DIR: OnceLock<PathBuf> = OnceLock::new();
 static TAURI_DIR: OnceLock<PathBuf> = OnceLock::new();
 
 pub fn walk_builder(path: &Path) -> WalkBuilder {
@@ -79,6 +79,7 @@ fn env_tauri_app_path() -> Option<PathBuf> {
     .ok()?
     .canonicalize()
     .ok()
+    .map(|p| dunce::simplified(&p).to_path_buf())
 }
 
 fn env_tauri_frontend_path() -> Option<PathBuf> {
@@ -87,10 +88,11 @@ fn env_tauri_frontend_path() -> Option<PathBuf> {
     .ok()?
     .canonicalize()
     .ok()
+    .map(|p| dunce::simplified(&p).to_path_buf())
 }
 
 pub fn resolve_tauri_dir() -> Option<PathBuf> {
-  let src_dir = env_tauri_frontend_path().or_else(|| current_dir().ok())?;
+  let src_dir = env_tauri_app_path().or_else(|| current_dir().ok())?;
 
   if src_dir.join(ConfigFormat::Json.into_file_name()).exists()
     || src_dir.join(ConfigFormat::Json5.into_file_name()).exists()
@@ -113,7 +115,7 @@ pub fn resolve_tauri_dir() -> Option<PathBuf> {
 
 pub fn resolve() {
   TAURI_DIR.set(resolve_tauri_dir().unwrap_or_else(|| {
-    let env_var_name = env_tauri_frontend_path().is_some().then(|| format!("`{ENV_TAURI_FRONTEND_PATH}`"));
+    let env_var_name = env_tauri_app_path().is_some().then(|| format!("`{ENV_TAURI_APP_PATH}`"));
     panic!("Couldn't recognize the {} folder as a Tauri project. It must contain a `{}`, `{}` or `{}` file in any subfolder.",
       env_var_name.as_deref().unwrap_or("current"),
       ConfigFormat::Json.into_file_name(),
@@ -121,8 +123,8 @@ pub fn resolve() {
       ConfigFormat::Toml.into_file_name()
     )
   })).expect("tauri dir already resolved");
-  APP_DIR
-    .set(resolve_app_dir().unwrap_or_else(|| tauri_dir().parent().unwrap().to_path_buf()))
+  FRONTEND_DIR
+    .set(resolve_frontend_dir().unwrap_or_else(|| tauri_dir().parent().unwrap().to_path_buf()))
     .expect("app dir already resolved");
 }
 
@@ -132,14 +134,15 @@ pub fn tauri_dir() -> &'static PathBuf {
     .expect("app paths not initialized, this is a Tauri CLI bug")
 }
 
-pub fn resolve_app_dir() -> Option<PathBuf> {
-  let app_dir = env_tauri_app_path().unwrap_or_else(|| current_dir().expect("failed to read cwd"));
+pub fn resolve_frontend_dir() -> Option<PathBuf> {
+  let frontend_dir =
+    env_tauri_frontend_path().unwrap_or_else(|| current_dir().expect("failed to read cwd"));
 
-  if app_dir.join("package.json").exists() {
-    return Some(app_dir);
+  if frontend_dir.join("package.json").exists() {
+    return Some(frontend_dir);
   }
 
-  lookup(&app_dir, |path| {
+  lookup(&frontend_dir, |path| {
     if let Some(file_name) = path.file_name() {
       file_name == OsStr::new("package.json")
     } else {
@@ -149,8 +152,8 @@ pub fn resolve_app_dir() -> Option<PathBuf> {
   .map(|p| p.parent().unwrap().to_path_buf())
 }
 
-pub fn app_dir() -> &'static PathBuf {
-  APP_DIR
+pub fn frontend_dir() -> &'static PathBuf {
+  FRONTEND_DIR
     .get()
     .expect("app paths not initialized, this is a Tauri CLI bug")
 }
