@@ -39,12 +39,13 @@ pub trait WindowExt {
 
   /// Clears the window sufrace. i.e make it it transparent.
   #[cfg(windows)]
-  fn clear_surface(
+  fn draw_surface(
     &self,
     surface: &mut softbuffer::Surface<
       std::sync::Arc<tao::window::Window>,
       std::sync::Arc<tao::window::Window>,
     >,
+    background_color: Option<tao::window::RGBA>,
   );
 }
 
