@@ -30,7 +30,7 @@ use crate::{
 
 use super::{
   window::{DragDropPayload, DRAG_DROP_EVENT, DRAG_ENTER_EVENT, DRAG_LEAVE_EVENT, DRAG_OVER_EVENT},
-  AppManager,
+  {AppManager, EmitPayload},
 };
 
 // we need to proxy the dev server on mobile because we can't use `localhost`, so we use the local IP address
@@ -226,16 +226,13 @@ impl<R: Runtime> WebviewManager<R> {
       let protocol = protocol.clone();
       let app_handle = manager.app_handle().clone();
 
-      pending.register_uri_scheme_protocol(
-        uri_scheme.clone(),
-        move |webview_id, request, responder| {
-          let context = UriSchemeContext {
-            app_handle: &app_handle,
-            webview_label: webview_id,
-          };
-          (protocol.protocol)(context, request, UriSchemeResponder(responder))
-        },
-      );
+      pending.register_uri_scheme_protocol(uri_scheme, move |webview_id, request, responder| {
+        let context = UriSchemeContext {
+          app_handle: &app_handle,
+          webview_label: webview_id,
+        };
+        (protocol.protocol)(context, request, UriSchemeResponder(responder))
+      });
     }
 
     let window_url = Url::parse(&pending.url).unwrap();
@@ -314,7 +311,7 @@ impl<R: Runtime> WebviewManager<R> {
         .get::<crate::Scopes>()
         .asset_protocol
         .clone();
-      let protocol = crate::protocol::asset::get(asset_scope.clone(), window_origin.clone());
+      let protocol = crate::protocol::asset::get(asset_scope, window_origin.clone());
       pending.register_uri_scheme_protocol("asset", move |webview_id, request, responder| {
         protocol(webview_id, request, UriSchemeResponder(responder))
       });
@@ -631,12 +628,14 @@ impl<R: Runtime> WebviewManager<R> {
         .expect("failed to run on_webview_created hook");
     }
 
-    let _ = webview.manager.emit(
-      crate::EventName::from_str("tauri://webview-created"),
-      &Some(crate::webview::CreatedEvent {
-        label: webview.label().into(),
-      }),
-    );
+    let event = crate::EventName::from_str("tauri://webview-created");
+    let payload = Some(crate::webview::CreatedEvent {
+      label: webview.label().into(),
+    });
+
+    let _ = webview
+      .manager
+      .emit(event, EmitPayload::Serialize(&payload));
 
     webview
   }
@@ -660,12 +659,13 @@ impl<R: Runtime> WebviewManager<R> {
 
 impl<R: Runtime> Webview<R> {
   /// Emits event to [`EventTarget::Window`] and [`EventTarget::WebviewWindow`]
-  fn emit_to_webview<S: Serialize + Clone>(
+  fn emit_to_webview<S: Serialize>(
     &self,
     event: crate::EventName<&str>,
-    payload: S,
+    payload: &S,
   ) -> crate::Result<()> {
     let window_label = self.label();
+    let payload = EmitPayload::Serialize(payload);
     self
       .manager()
       .emit_filter(event, payload, |target| match target {
@@ -685,14 +685,14 @@ fn on_webview_event<R: Runtime>(webview: &Webview<R>, event: &WebviewEvent) -> c
           paths: Some(paths),
           position,
         };
-        webview.emit_to_webview(DRAG_ENTER_EVENT, payload)?
+        webview.emit_to_webview(DRAG_ENTER_EVENT, &payload)?
       }
       DragDropEvent::Over { position } => {
         let payload = DragDropPayload {
           position,
           paths: None,
         };
-        webview.emit_to_webview(DRAG_OVER_EVENT, payload)?
+        webview.emit_to_webview(DRAG_OVER_EVENT, &payload)?
       }
       DragDropEvent::Drop { paths, position } => {
         let scopes = webview.state::<Scopes>();
@@ -707,9 +707,9 @@ fn on_webview_event<R: Runtime>(webview: &Webview<R>, event: &WebviewEvent) -> c
           paths: Some(paths),
           position,
         };
-        webview.emit_to_webview(DRAG_DROP_EVENT, payload)?
+        webview.emit_to_webview(DRAG_DROP_EVENT, &payload)?
       }
-      DragDropEvent::Leave => webview.emit_to_webview(DRAG_LEAVE_EVENT, ())?,
+      DragDropEvent::Leave => webview.emit_to_webview(DRAG_LEAVE_EVENT, &())?,
       _ => unimplemented!(),
     },
   }
