@@ -30,7 +30,12 @@ import {
   once
 } from './event'
 import { invoke } from './core'
-import { Color, Window, getCurrentWindow } from './window'
+import {
+  BackgroundThrottlingPolicy,
+  Color,
+  Window,
+  getCurrentWindow
+} from './window'
 import { WebviewWindow } from './webviewWindow'
 
 /** The drag and drop event types. */
@@ -767,6 +772,25 @@ interface WebviewOptions {
    * @since 2.1.0
    */
   backgroundColor?: Color
+
+  /** Change the default background throttling behaviour.
+   *
+   * By default, browsers use a suspend policy that will throttle timers and even unload
+   * the whole tab (view) to free resources after roughly 5 minutes when a view became
+   * minimized or hidden. This will pause all tasks until the documents visibility state
+   * changes back from hidden to visible by bringing the view back to the foreground.
+   *
+   * ## Platform-specific
+   *
+   * - **Linux / Windows / Android**: Unsupported. Workarounds like a pending WebLock transaction might suffice.
+   * - **iOS**: Supported since version 17.0+.
+   * - **macOS**: Supported since version 14.0+.
+   *
+   * see https://github.com/tauri-apps/tauri/issues/5250#issuecomment-2569380578
+   *
+   * @since 2.3.0
+   */
+  backgroundThrottling?: BackgroundThrottlingPolicy
 }
 
 export { Webview, getCurrentWebview, getAllWebviews }
